==> phpbb2_2.0.13+1.orig.tar.gz: lang_korean/lang_faq.php <==
<?php
/***************************************************************************
 *                          lang_faq.php [english]
 *                            -------------------
 *   begin                : Wednesday Oct 3, 2001
 *   copyright            : (C) 2001 The phpBB Group
 *   email                : support@phpbb.com
 *
 *   $Id: lang_faq.php,v 1.1.2.1 2002/09/28 13:29:53 psotfx Exp $
 *
 *
 ***************************************************************************/
/* 2002/09/12 Translated by TankTonk */
/* 2002/12/17 update by Soon-Son Kwon(kss@kldp.org) */
/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//
// To add an entry to your FAQ simply add a line to this file in this format:
// $faq[] = array("question", "answer");
// If you want to separate a section enter $faq[] = array("--","Block heading goes here if wanted");
// Links will be created automatically
//
// DO NOT forget the ; at the end of the line.
// Do NOT put double quotes (") in your FAQ entries, if you absolutely must then escape them ie. \"something\";
//
// The FAQ items will appear on the FAQ page in the same order they are listed in this file
//


$faq[] = array("--","αΰ  ");
$faq[] = array(" α ȵǳ?", " ϼ̽ϱ? αϷ   ؾ մϴ. Խǿ   ƴѰ(׷  ޽ ɴϴ)?  ׷ٸ, ͳ Խ ڸ Ͻʽÿ. ϵ ߰  ͵ ƴϸ鼭 α ȵǸ  ̸ йȣ ٽ ѹ Ȯ . ̻ Ϲ Դϴ, ׷ ȵǸ Խ ڸ Ͻʽÿ. Խ  ߸ Ǿ  ֽϴ.");
$faq[] = array("  ؾ ϳ?", "ݵ  ʿ ϴ,   ؼ  ؾ ϴ Խ ڰ մϴ. ׷  ϰ Ǹ մԿԴ ־ ʴ ΰ ɵ, ƹŸ,  ޽, ϸ,  ׷   ˴ϴ.  ø ǹǷ   մϴ.");
$faq[] = array(" ڵ α׾ƿǳ?", "α  <i>ڵ α</i> ڽ üũ   ð Խ ڸ α ƿմϴ. ̰ ٸ   ϴ  ݴϴ.  α ·  α   ڽ üũ Ͻʽÿ, ̳ ͳ    ǻ͸ ϴ   ʴ  ϴ.");
$faq[] = array("  ̸   Ʈ  ʰ Ϸ?", "   <i>¶  </i> ɼ ֽϴ, ̰ ٲٸ ڱ ڽŰ Խ ڿԸ   ڷ ޵˴ϴ.");
$faq[] = array("йȣ ؾ!", "ʽÿ! йȣ ˾Ƴ   ʱȭ   ֽϴ. α ȭ  <u> ȣ ؾ</u> Ŭ , ȭ ÿ   Խ ٽ   ֽϴ.");
$faq[] = array(" ߴµ α ȵǿ!", "켱  ̸ йȣ Ȯ ʽÿ.  ԷϿٸ  ΰ ߿ ϳ ߻  ֽϴ.  COPPA  밡 Ǿ ְ  ÿ <u>13 ̸Դϴ</u>  Ŭߴٸ  ø ߸ մϴ.  찡 ƴ϶   ʿմϴ? Ϻ Խ ο Ͻÿ α  ̳ Խ ڷκ  䱸մϴ.     ʿ θ ˷ ݴϴ. ̸ ޾Ҵٸ û ʽÿ, ̸  ʾҴٸ ̸ ּҰ Ȯ Ȯ ʽÿ.  ϴ    Խ ϴ    Դϴ. ̸ ּҰ Ȯϴٸ Խ ڸ  ʽÿ.");
$faq[] = array("ſ  ߴµ  ̻ α ȵ˴ϴ?!", "κ   ̸ йȣ ߸ Է߰ų(Ͻÿ  ̸ ) ڰ      ϴ.   ø   ʽϱ? ͺ̽ δ ̱ Ͽ ƹ͵ ø ʴ ڸ ֱ ϴ°  ߼Դϴ. Ͻð п  Ͻʽÿ.");


$faq[] = array("--"," ");
$faq[] = array("   ٲٳ?", "  ͺ̽ Ǿ ֽϴ. Ϸ  <u> </u> ũ(Ϲ ȭ ܿ ) ŬϽʽÿ. ⿡     ֽϴ");
$faq[] = array("ð Ʋϴ!", "ð  ½ϴٸ ð밡 ߸ Ǿ   ֽϴ.  ׷ٸ   ùٸ ð븦 Ͻʽÿ. ð  ٸ   ϵ ڸ   ֽϴ. ׷Ƿ    ߴٸ   Ͻʽÿ.");
$faq[] = array("ð븦 ߴµ ð Ʋϴ!", "ð븦 Ȯ ߾µ ð Ʋٸ Ƹ ϱ  ð(Ȥ Ÿ) Դϴ.  Խ  ð ̿    Ƿ ̰   ֽϴ.");
$faq[] = array(" ϴ  Ʈ ϴ!", "ڰ ش  ġ ʾҰų Խ ش     Դϴ. Խ ڿ ʿ  ġ 䱸ϰų,    ٸ  ѹ õ ʽÿ.  ڼ  phpBB ׷ Ʈ Ͻʽÿ");
$faq[] = array("  ̸ Ʒ ̹ ǥմϱ?", " ̸ ؿ ΰ ̹ ǥõ  ֽϴ. ù° ޿ õ  ̳  ǥõǴµ 󸶳   ÷ȴ° Ȥ Խǿ ġ ΰ ˷ ݴϴ.  ؿ ƹŸ ˷ ̹ ǥõ  ִµ, ̰  ڿ մϴ. ƹŸ   ƹŸ ϴ  ڿ ޷ ֽϴ. ƹŸ    Ǿ  ̰ Խ  ̹Ƿ ڿ   ʽÿ.");
$faq[] = array("  ٲٳ?", "Ϲ   ٲܼ ϴ(  ̸ ؿ ǥõǸ    ϴ). κ Խ ø   ǥϱ Ͽ  ϰų Ư ڸ ǥϴµ  ϴµ Խ ڳ ڰ  Դϴ.   ø Ͽ   ø  ﰡϱ ٶϴ, ڳ ڰ  ų  ֽϴ.");
$faq[] = array("̸ ũ Ŭϴϱ α϶ ϴµ?", "ϵ ڸ  ̸  Ͽ ̸   ֽϴ(ڰ     쿡). ̰  ڰ ̸ ý ϴ   Դϴ.");


$faq[] = array("--","۾ ");
$faq[] = array("Խǿ   ø?", " , Խ̳  ȭ鿡  ư ŬϽʽÿ.  ø   Ǿ ־ մϴ,   ִ ɵ ȭ Ʒ Ǿ ֽϴ (<i>۾, ǥϱ </i> Ʈ)");
$faq[] = array("ø  ϰų 쳪?", "Խ ڳ ڰ ƴ   ڱⰡ ø ۸ ,  մϴ. ñ <i></i> ư ŬϿ   ֽϴ. ̹   ٸ,   ؿ ̳  ߴ Ÿ ؽƮ ǥõ˴ϴ. ƹ   ʾҴٸ ǥð  , ڳ ڰ   (   Դϴ) ƹ͵ Ÿ ʽϴ.   Ϲ ڴ Խù   ϴ.");
$faq[] = array("Խù   ߰ϳ?", "Խù  ߰Ϸ   ־ ϴµ      ֽϴ.  غǾ  Խù Ļ <i> ߰</i> ڽ üũϿ  ߰մϴ.   ش ɼ üũϿ ⺻   ۿ ߰ϵ   ֽϴ(Խù    ߰ ڽ üũ    ߰ ϰ   ֽϴ)");
$faq[] = array("ǥ  峪?", "ǥ   ϴ, ο  ø (Ȥ  鼭  ) <i>ǥ ߰</i>    ֽϴ ( ã ٸ ǥ     Դϴ). ǥ  Էϰ ּ   ɼ Ͻʽÿ(ɼ Ϸ ǥ  Էϰ <i>ɼ ߰</i> ư ŬϽʽÿ. , ǥ ð   ִµ, 0  Ѵ ǥԴϴ.   ɼ   ִµ ̰ ڰ մϴ");
$faq[] = array(" ǥ ϰų ϳ?", "ø ۰  ǥ   Խ   ڸ   ֽϴ. ǥ Ϸ ù°  ۸Ͻʽÿ(ù°   ǥ Ǿ ֽϴ). ƹ ǥ ߴٸ ǥ ϰų  ǥ ɼ   , ̹ ǥ Ǿٸ ڿ ڸ    մϴ. ̰ ǥ ߰ ɼǵ ٲν ǥ  ִ    Դϴ");
$faq[] = array(" Խǿ   ǳ?", "Ϻ Խǵ Ư ڵ ׷쿡Ը ѵǾ   ֽϴ.    аų  Ư 㰡 ʿѵ,  Խ ڿ ڸ    Ƿ ̵ ؾ մϴ.");
$faq[] = array(" ǥ   ?", " ǥ  Ͽ  ϵ ڸ ǥ   ֽϴ. ϵ ε ǥ   ٸ ش   Դϴ.");


$faq[] = array("--","ð  ");
$faq[] = array("BBCode?", "BBCode HTML Ư ν BBCode   δ ڰ մϴ (  Ŀ  ۿ Ͽ  BBCode   ֽϴ). BBCode ŸϿ ־ HTML Ͽ , ±״ &lt;  &gt; ſ ȣ [  ] ȿ ,   ǥ  ϰ մϴ. BBCode   ڼ   Ͻʽÿ.");
$faq[] = array("HTML   ֳ?", "װ ڰ մϴ.   ϴٸ Ҽ ±׵鸸  Դϴ. ̰ Ϻ  ±׸ Ͽ Խ ġų ϴ    <i>å</i> Դϴ. HTML  Խ Ŀ   ֽϴ.");
$faq[] = array(" Դϱ?", "̳ ̸Ƽ  ڵ带 ̿Ͽ  ϴµ Ǵ  ̹ Դϴ,   :)  ڴ, :(  . ̸Ƽ Ʈ Խ Ŀ ֽϴ. ʹ    б ư Ƿ   Ͻʽÿ, ڰ Ƿ  Ǵ  ü   ֽϴ");
$faq[] = array("̹ ø  ֳ?", "̹ ̰Դ   ֽϴ. ׷   Խ  ̹ ø  ϴ.  ̹      ־ ũ ؾ մϴ.  ǻ(  ƴϸ) ִ ̹  ġ  ִ ̹ ũ  ϴ. ̹ ǥϷ BBCode [img] ±׳ HTML ̿Ͻʽÿ.");
$faq[] = array(" ΰ?", "  ߿  ˸Ƿ  д  ϴ.  Խ   ġմϴ.  ø  ִ ڰ ϴ  ־ մϴ.");
$faq[] = array("  ΰ?", "   ٷ ؿ, ׸ ù°  ɴϴ.  ߿  ϹǷ  д  ϴ.   ڰ  ־ ø  ֽϴ.");
$faq[] = array("  ?", " Խ ڳ Խ ڰ   ֽϴ.        ȿ ִ ǥ ڵ ˴ϴ.       ֽϴ.");


$faq[] = array("--"," ް ׷");
$faq[] = array("ڶ?", "ڶ Խ ü Ʋ ְ    մϴ. ̵  ,  ,  ׷     Խ     ֽϴ.  ׵  Խǿ  ѵ  ֽϴ.");
$faq[] = array("ڶ?", "ڴ Խ ϴ ̳ ׷ մϴ. ̵ ڽ ϴ Խǳ  , , , , ̵  и    ִ   ֽϴ. Ϲ ڵ  ų ۿø⸦ ϰų     մϴ.");
$faq[] = array(" ׷̶?", " ׷̶ ڰ ڵ иϴ 浵Դϴ.  ڴ  ׷쿡   (ٸ Խǿ ƴ  )  ׷ ش   ο ޽ϴ. ̷ν ڴ  Ϻ ڸ ڷ ϰų  Խǿ     ֽϴ.");
$faq[] = array(" ׷   ϳ?", " ׷쿡 Ϸ   ִ ڱ׷ ũ Ŭϸ   ׷    Դϴ.  ׷ <i> </i> ƴϸ Ϻδ , Ϻδ   ֽϴ. ϴ ׷ Ǿ  ش ư ŬϿ  û   ֽϴ.  ׷ ڰ û ؾ ϸ     ֽϴ.");
$faq[] = array(" ׷ ڴ  ǳ?", " ׷ Խ ڿ ؼ  Խ ڷ ˴ϴ.  ׷   켱 ڸ Ͻʽÿ.");


$faq[] = array("--"," ޽");
$faq[] = array(" ޽   !", "    ֽϴ; ϵ ʾҰų α ʾҽϴ, Խ ڰ ü Խǿ Ͽ  ޽   ҽϴ,  Խ ڰ   ޽   ҽϴ.   쿡 شȴٸ ڿ   ٶϴ.");
$faq[] = array("  ʴ ޽  ɴϴ!", " ̷  ޽ ɿ    Դϴ.  ʴ  ޽    ޴´ٸ ڿ ˸ʽÿ, ׵  ޽  ϵ ϴ  ϱ.");
$faq[] = array(" Խǿ ִ κ Ը ް ֽϴ!", "̱.  Խ ̸ ɿ ׷    ؼ   ֽϴ.   ÷Ͽ Խ ڿ ̸ ʽÿ, (̸    ڼ  ) ݵ Ͽ մϴ. ׷  ġ  Դϴ.");

//
// These entries should remain in all languages and for all modifications
//
$faq[] = array("--","phpBB 2 ");
$faq[] = array("  Խ α׷ ?", " α׷ <a href=\"http://www.phpbb.com/\" target=\"_blank\">phpBB Group</a> ׷쿡 ؼ , Ǹ ۱ ֽϴ. GNU General Public Licence Ͽ  Ǹ   ֽϴ,  ڼ  ũ ϼ");
$faq[] = array(" ̷  ?", " α׷ phpBB ׷쿡 ؼ  ̼ ֽϴ.   ʿϽôٸ phpbb.com Ʈ 湮ϼż phpBB ׷ ǰ  ʽÿ. ϴ  phpbb.com Խǿ ø ʽÿ, ׷ sourceforge ̿Ͽ ο   ϰ ֽϴ. ϴ ɿ  ׷  ̹ ִ  Ȯ  ׷    ٶϴ.");
$faq[] = array(" Խǿ Ͽ ̳    ؾ ϳ?", " Խ ڿ Ͻʽÿ. ڰ     Խ ڸ Ͽ ϱ ٶϴ. ׷    ڸ ϰų,  Խ  ȣƮ(yahoo, free.fr, f2s.com )󿡼 ϰ ִٸ   ش μ Ͻʽÿ. phpBB ׷  Խ α׷  ؼ  𿡼 Ǵ  ƹ     մϴ. phpBB.com Ʈ phpBB α׷ ü    ܿ    Ͽ phpBB ׷ ϴ   ǹմϴ.  ڰ  Ʈ ϴ Ϳ   phpBB ׷   亯 Ȥ   ֽϴ.");

//
// This ends the FAQ entries
//

?>

==> phpbb2_2.0.21.orig.tar.gz: lang_korean/lang_faq.php <==
<?php
/***************************************************************************
 *                          lang_faq.php [Korean]
 *                            -------------------
 *   begin                : Wednesday Oct 3, 2001
 *   copyright            : (C) 2001 The phpBB Group
 *   email                : support@phpbb.com
 *
 *   $Id: lang_faq.php,v 1.4.2.3 2002/12/18 15:40:20 psotfx Exp $
 *
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/* CONTRIBUTORS
	2002-12-15	Philip M. White (pwhite@mailhaven.com)
		Fixed many minor grammatical problems.
	2002-08-28	TankTonk
		FIrst Translation
	2002-12-17	Soon-Son Kwon(kss@kldp.org)
		Update
	2005-02-26	Seok-moon Jang(drssay@gmail.com)
		Update to 2.0.12
*/
 
// 
// To add an entry to your FAQ simply add a line to this file in this format:
// $faq[] = array("question", "answer");
// If you want to separate a section enter $faq[] = array("--","Block heading goes here if wanted");
// Links will be created automatically
//
// DO NOT forget the ; at the end of the line.
// Do NOT put double quotes (") in your FAQ entries, if you absolutely must then escape them ie. \"something\"
//
// The FAQ items will appear on the FAQ page in the same order they are listed in this file
//
 
$faq[] = array("--","αΰ  ");
$faq[] = array(" α ȵǳ?", " ϼ̽ϱ? αϷ   ؾ մϴ. Խǿ   ƴѰ(׷  ޽ ɴϴ)?  ׷ٸ, ͳ Խ ڸ Ͻʽÿ. ϵ ߰  ͵ ƴϸ鼭 α ȵǸ  ̸ йȣ ٽ ѹ Ȯ . ̻ Ϲ Դϴ, ׷ ȵǸ Խ ڸ Ͻʽÿ. Խ  ߸ Ǿ  ֽϴ.");
$faq[] = array("  ؾ ϳ?", "ݵ  ʿ ϴ,   ؼ  ؾ ϴ Խ ڰ մϴ. ׷  ϰ Ǹ մԿԴ ־ ʴ ΰ ɵ, ƹŸ,  ޽, ϸ,  ׷   ˴ϴ.  ø ǹǷ   մϴ.");
$faq[] = array(" ڵ α׾ƿǳ?", "α  <i>ڵ α</i> ڽ üũ   ð Խ ڸ α ƿմϴ. ̰ ٸ   ϴ  ݴϴ.  α ·  α   ڽ üũ Ͻʽÿ, ̳ ͳ    ǻ͸ ϴ   ʴ  ϴ.");
$faq[] = array("  ̸   Ʈ  ʰ Ϸ?", "   <i>¶  </i> ɼ ֽϴ, ̰ ٲٸ ڱ ڽŰ Խ ڿԸ   ڷ ޵˴ϴ.");
$faq[] = array("йȣ ؾ!", "ʽÿ! йȣ ˾Ƴ   ʱȭ   ֽϴ. α ȭ  <u> ȣ ؾ</u> Ŭ , ȭ ÿ   Խ ٽ   ֽϴ.");
$faq[] = array(" ߴµ α ȵǿ!", "켱  ̸ йȣ Ȯ ʽÿ.  ԷϿٸ  ΰ ߿ ϳ ߻  ֽϴ.  COPPA  밡 Ǿ ְ  ÿ <u>13 ̸Դϴ</u>  Ŭߴٸ  ø ߸ մϴ.  찡 ƴ϶   ʿմϴ? Ϻ Խ ο Ͻÿ α  ̳ Խ ڷκ  䱸մϴ.     ʿ θ ˷ ݴϴ. ̸ ޾Ҵٸ û ʽÿ, ̸  ʾҴٸ ̸ ּҰ Ȯ Ȯ ʽÿ.  ϴ    Խ ϴ    Դϴ. ̸ ּҰ Ȯϴٸ Խ ڸ  ʽÿ.");
$faq[] = array("ſ  ߴµ  ̻ α ȵ˴ϴ?!", "κ   ̸ йȣ ߸ Է߰ų(Ͻÿ  ̸ ) ڰ      ϴ.   ø   ʽϱ? ͺ̽ δ ̱ Ͽ ƹ͵ ø ʴ ڸ ֱ ϴ°  ߼Դϴ. Ͻð п  Ͻʽÿ.");  


$faq[] = array("--"," ");
$faq[] = array("   ٲٳ?", " () ͺ̽ Ǿ ֽϴ. Ϸ  <u> </u> ũ(Ϲ ȭ ܿ ) ŬϽʽÿ. ⿡     ֽϴ");
$faq[] = array("ð Ʋϴ!", "ð  ½ϴٸ ð밡 ߸ Ǿ   ֽϴ.  ׷ٸ   ùٸ ð븦 Ͻʽÿ. ð  ٸ   ϵ ڸ   ֽϴ. ׷Ƿ    ߴٸ   Ͻʽÿ.");
$faq[] = array("ð븦 ߴµ ð Ʋϴ!", "ð븦 Ȯ ߾µ ð Ʋٸ Ƹ ϱ  ð(Ȥ Ÿ) Դϴ.  Խ  ð ̿    Ƿ ̰   ֽϴ.");
$faq[] = array(" ϴ  Ʈ ϴ!", "ڰ ش  ġ ʾҰų Խ ش     Դϴ. Խ ڿ ʿ  ġ 䱸ϰų,    ٸ  ѹ õ ʽÿ.  ڼ  phpBB ׷ Ʈ Ͻʽÿ(see link at bottom of pages)");
$faq[] = array("  ̸ Ʒ ̹ ǥմϱ?", " ̸ ؿ ΰ ̹ ǥõ  ֽϴ. ù° ޿ õ  ̳  ǥõǴµ 󸶳   ÷ȴ° Ȥ Խǿ ġ ΰ ˷ ݴϴ.  ؿ ƹŸ ˷ ̹ ǥõ  ִµ, ̰  ڿ մϴ. ƹŸ   ƹŸ ϴ  ڿ ޷ ֽϴ. ƹŸ    Ǿ  ̰ Խ  ̹Ƿ ڿ   ʽÿ.");
$faq[] = array("  ٲٳ?", "Ϲ   ٲܼ ϴ(  ̸ ؿ ǥõǸ    ϴ). κ Խ ø   ǥϱ Ͽ  ϰų Ư ڸ ǥϴµ  ϴµ Խ ڳ ڰ  Դϴ.   ø Ͽ   ø  ﰡϱ ٶϴ, ڳ ڰ  ų  ֽϴ.");
$faq[] = array("̸ ũ Ŭϴϱ α϶ ϴµ?", "ϵ ڸ  ̸  Ͽ ̸   ֽϴ(ڰ     쿡). ̰ ͸ ڰ ̸ ý ϴ   Դϴ.");


$faq[] = array("--","۾ ");
$faq[] = array("Խǿ   ø?", " , Խ̳  ȭ鿡  ư ŬϽʽÿ.  ø   Ǿ ־ մϴ,   ִ ɵ ȭ Ʒ Ǿ ֽϴ (<i>۾, ǥϱ </i> Ʈ)");
$faq[] = array("ø  ϰų 쳪?", "Խ ڳ ڰ ƴ   ڱⰡ ø ۸ ,  մϴ. ñ <i></i> ư ŬϿ   ֽϴ. ̹   ٸ,   ؿ ̳  ߴ Ÿ ؽƮ ǥõ˴ϴ. ƹ   ʾҴٸ ǥð  , ڳ ڰ   (   Դϴ) ƹ͵ Ÿ ʽϴ.   Ϲ ڴ Խù   ϴ.");
$faq[] = array("Խù   ߰ϳ?", "Խù  ߰Ϸ   ־ ϴµ      ֽϴ.  غǾ  Խù Ļ <i> ߰</i> ڽ üũϿ  ߰մϴ.   ش ɼ üũϿ ⺻   ۿ ߰ϵ   ֽϴ(Խù    ߰ ڽ üũ    ߰ ϰ   ֽϴ)");
$faq[] = array("ǥ  峪?", "ǥ   ϴ, ο  ø (Ȥ  鼭  ) <i>ǥ ߰</i>    ֽϴ ( ã ٸ ǥ     Դϴ). ǥ  Էϰ ּ   ɼ Ͻʽÿ(ɼ Ϸ ǥ  Էϰ <i>ɼ ߰</i> ư ŬϽʽÿ. , ǥ ð   ִµ, 0  Ѵ ǥԴϴ.   ɼ   ִµ ̰ ڰ մϴ");
$faq[] = array(" ǥ ϰų ϳ?", "ø ۰  ǥ   Խ   ڸ   ֽϴ. ǥ Ϸ ù°  ۸Ͻʽÿ(ù°   ǥ Ǿ ֽϴ). ƹ ǥ ߴٸ ǥ ϰų  ǥ ɼ   , ̹ ǥ Ǿٸ ڿ ڸ    մϴ. ̰ ǥ ߰ ɼǵ ٲν ǥ  ִ    Դϴ");
$faq[] = array(" Խǿ   ǳ?", "Ϻ Խǵ Ư ڵ ׷쿡Ը ѵǾ   ֽϴ.    аų  Ư 㰡 ʿѵ,  Խ ڿ ڸ    Ƿ ̵ ؾ մϴ.");
$faq[] = array(" ǥ   ?", " ǥ  Ͽ  ϵ ڸ ǥ   ֽϴ. ϵ ε ǥ   ٸ ش   Դϴ.");


$faq[] = array("--","ð  ");
$faq[] = array("BBCode?", "BBCode HTML Ư ν BBCode   δ ڰ մϴ (  Ŀ  ۿ Ͽ  BBCode   ֽϴ). BBCode ŸϿ ־ HTML Ͽ , ±״ &lt;  &gt; ſ ȣ [  ] ȿ ,   ǥ  ϰ մϴ. BBCode   ڼ   Ͻʽÿ.");
$faq[] = array("HTML   ֳ?", "װ ڰ մϴ.   ϴٸ Ҽ ±׵鸸  Դϴ. ̰ Ϻ  ±׸ Ͽ Խ ġų ϴ    <i>å</i> Դϴ. HTML  Խ Ŀ   ֽϴ.");
$faq[] = array(" Դϱ?", "̳ ̸Ƽ  ڵ带 ̿Ͽ  ϴµ Ǵ  ̹ Դϴ,   :)  ڴ, :(  . ̸Ƽ Ʈ Խ Ŀ ֽϴ. ʹ    б ư Ƿ   Ͻʽÿ, ڰ Ƿ  Ǵ  ü   ֽϴ");
$faq[] = array("̹ ø  ֳ?", "̹ ̰Դ   ֽϴ. ׷   Խ  ̹ ø  ϴ.  ̹      ־ ũ ؾ մϴ.  ǻ(  ƴϸ) ִ ̹  ġ  ִ ̹ ũ  ϴ. ̹ ǥϷ BBCode [img] ±׳ HTML ̿Ͻʽÿ.");
$faq[] = array(" ΰ?", "  ߿  ˸Ƿ  д  ϴ.  Խ   ġմϴ.  ø  ִ ڰ ϴ  ־ մϴ.");
$faq[] = array("  ΰ?", "   ٷ ؿ, ׸ ù°  ɴϴ.  ߿  ϹǷ  д  ϴ.   ڰ  ־ ø  ֽϴ.");
$faq[] = array("  ?", " Խ ڳ Խ ڰ   ֽϴ.        ȿ ִ ǥ ڵ ˴ϴ.       ֽϴ.");
$faq[] = array("--","ð  ");
$faq[] = array("BBCode?", "BBCode HTML Ư ν BBCode   δ ڰ մϴ (  Ŀ  ۿ Ͽ  BBCode   ֽϴ). BBCode ŸϿ ־ HTML Ͽ , ±״ &lt;  &gt; ſ ȣ [  ] ȿ ,   ǥ  ϰ մϴ. BBCode   ڼ   Ͻʽÿ.");
$faq[] = array("HTML   ֳ?", "װ ڰ մϴ.   ϴٸ Ҽ ±׵鸸  Դϴ. ̰ Ϻ  ±׸ Ͽ Խ ġų ϴ    <i>å</i> Դϴ. HTML  Խ Ŀ   ֽϴ.");
$faq[] = array(" Դϱ?", "̳ ̸Ƽ  ڵ带 ̿Ͽ  ϴµ Ǵ  ̹ Դϴ,   :)  ڴ, :(  . ̸Ƽ Ʈ Խ Ŀ ֽϴ. ʹ    б ư Ƿ   Ͻʽÿ, ڰ Ƿ  Ǵ  ü   ֽϴ");
$faq[] = array("̹ ø  ֳ?", "̹ ̰Դ   ֽϴ. ׷   Խ  ̹ ø  ϴ.  ̹      ־ ũ ؾ մϴ.  ǻ(  ƴϸ) ִ ̹  ġ  ִ ̹ ũ  ϴ. ̹ ǥϷ BBCode [img] ±׳ HTML ̿Ͻʽÿ.");
$faq[] = array(" ΰ?", "  ߿  ˸Ƿ  д  ϴ.  Խ   ġմϴ.  ø  ִ ڰ ϴ  ־ մϴ.");
$faq[] = array("  ΰ?", "   ٷ ؿ, ׸ ù°  ɴϴ.  ߿  ϹǷ  д  ϴ.   ڰ  ־ ø  ֽϴ.");
$faq[] = array("  ?", " Խ ڳ Խ ڰ   ֽϴ.        ȿ ִ ǥ ڵ ˴ϴ.       ֽϴ.");


$faq[] = array("--"," ް ׷");
$faq[] = array("ڶ?", "ڶ Խ ü Ʋ ְ    մϴ. ̵  ,  ,  ׷     Խ     ֽϴ.  ׵  Խǿ  ѵ  ֽϴ.");
$faq[] = array("ڶ?", "ڴ Խ ϴ ̳ ׷ մϴ. ̵ ڽ ϴ Խǳ  , , , , ̵  и    ִ   ֽϴ. Ϲ ڵ  ų ۿø⸦ ϰų     մϴ.");
$faq[] = array(" ׷̶?", " ׷̶ ڰ ڵ иϴ 浵Դϴ.  ڴ  ׷쿡   (ٸ Խǿ ƴ  )  ׷ ش   ο ޽ϴ. ̷ν ڴ  Ϻ ڸ ڷ ϰų  Խǿ     ֽϴ.");
$faq[] = array(" ׷   ϳ?", " ׷쿡 Ϸ   ִ ڱ׷ ũ Ŭϸ   ׷    Դϴ.  ׷ <i> </i> ƴϸ Ϻδ , Ϻδ   ֽϴ. ϴ ׷ Ǿ  ش ư ŬϿ  û   ֽϴ.  ׷ ڰ û ؾ ϸ     ֽϴ.");
$faq[] = array(" ׷ ڴ  ǳ?", " ׷ Խ ڿ ؼ  Խ ڷ ˴ϴ.  ׷   켱 ڸ Ͻʽÿ.׷  ׵鿡  ޽ ʽÿ.");


$faq[] = array("--"," ޽");
$faq[] = array(" ޽   !", "    ֽϴ; ϵ ʾҰų α ʾҽϴ, Խ ڰ ü Խǿ Ͽ  ޽   ҽϴ,  Խ ڰ   ޽   ҽϴ.   쿡 شȴٸ ڿ   ٶϴ.");
$faq[] = array("  ʴ ޽  ɴϴ!", " ̷  ޽ ɿ    Դϴ.  ʴ  ޽    ޴´ٸ ڿ ˸ʽÿ, ׵  ޽  ϵ ϴ  ϱ.");
$faq[] = array(" Խǿ ִ κ Ը ް ֽϴ!", "̱.  Խ ̸ ɿ ׷    ؼ   ֽϴ.   ÷Ͽ Խ ڿ ̸ ʽÿ, (̸    ڼ  ) ݵ Ͽ մϴ. ׷  ġ  Դϴ.");

//
// These entries should remain in all languages and for all modifications
//
$faq[] = array("--","phpBB 2 ");
$faq[] = array("  Խ α׷ ?", " α׷ <a href=\"http://www.phpbb.com/\" target=\"_blank\">phpBB Group</a> ׷쿡 ؼ , Ǹ ۱ ֽϴ. GNU General Public Licence Ͽ  Ǹ   ֽϴ,  ڼ  ũ ϼ");
$faq[] = array(" ̷  ?", " α׷ phpBB ׷쿡 ؼ  ̼ ֽϴ.   ʿϽôٸ phpbb.com Ʈ 湮ϼż phpBB ׷ ǰ  ʽÿ. ϴ  phpbb.com Խǿ ø ʽÿ, ׷ sourceforge ̿Ͽ ο   ϰ ֽϴ. ϴ ɿ  ׷  ̹ ִ  Ȯ  ׷    ٶϴ.");
$faq[] = array(" Խǿ Ͽ ̳    ؾ ϳ?", " Խ ڿ Ͻʽÿ. ڰ     Խ ڸ Ͽ ϱ ٶϴ. ׷    ڸ ϰų,  Խ  ȣƮ(yahoo, free.fr, f2s.com )󿡼 ϰ ִٸ   ش μ Ͻʽÿ. phpBB ׷  Խ α׷  ؼ  𿡼 Ǵ  ƹ     մϴ. phpBB.com Ʈ phpBB α׷ ü    ܿ    Ͽ phpBB ׷ ϴ   ǹմϴ.  ڰ  Ʈ ϴ Ϳ   phpBB ׷   亯 Ȥ   ֽϴ.");

//
// This ends the FAQ entries
//

?>
